Crate avian_rerecast

Crate avian_rerecast 

Backend for using avian3d with bevy_rerecast.

Modules

prelude
Everything you need to get started with the Navmesh plugin.

Structs

AvianBackendPlugin
The plugin of the crate. Will make all entities with Collider a collider belonging to a static RigidBody available for navmesh generation.
ExcludeColliderFromNavmesh
Component to opt-out a Collider or RigidBody from navmesh generation when using AvianBackendPlugin. If that backend is not used, this component has no effect.

Traits

ColliderToTriMesh
Convenience trait that allows a Collider to be converted into a TriMesh.